==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/et_EE.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Keskmine koormus",
    "Last minute" : "Viimane minut",
    "Memory info not available" : "Mälu info pole saadaval",
    "Total" : "Kokku",
    "Current usage" : "Praegune kasutus",
    "Users" : "Kasutajad",
    "Groups" : "Grupid",
    "Links" : "Lingid",
    "Federated sent" : "Föderatsioonis saadetud",
    "Federated received" : "Föderatsioonis vastu võetud",
    "Last 24 hours" : "Viimased 24 tundi",
    "Last 1 hour" : "Viimane 1 tund",
    "Last 5 mins" : "Viimased 5 minutit",
    "Monitoring" : "Monitooring",
    "CPU load" : "CPU koormus",
    "Memory usage" : "Mälukasutus",
    "Active users" : "Aktiivseid kasutajaid",
    "Shares" : "Jagamisi",
    "Storage" : "Andmehoidlad",
    "Users:" : "Kasutajaid:",
    "Files:" : "Faile:",
    "PHP" : "PHP",
    "Version:" : "Versioon:",
    "Memory Limit:" : "Mälupiirang:",
    "Max Execution Time:" : "Maksimaalne käivitusaeg:",
    "Upload max size:" : "Maksimaalne üleslaadimissuurus:",
    "Database" : "Andmebaas",
    "Type:" : "Tüüp:",
    "Size:" : "Suurus:",
    "External monitoring tool" : "Väline monitoorimistööriist",
    "You can connect an external monitoring tool by using this end point: " : "Saad ühendada välise monitoorimistööriista kasutades seda lõpp-punkti:",
    "Server info" : "Serveri info",
    "You can connect a external monitoring tool by using this end point: " : "Saad ühendada välise monitoorimistööriista kasutades seda lõpp-punkti:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/et_EE.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Keskmine koormus",
    "Last minute" : "Viimane minut",
    "Memory info not available" : "Mälu info pole saadaval",
    "Total" : "Kokku",
    "Current usage" : "Praegune kasutus",
    "Users" : "Kasutajad",
    "Groups" : "Grupid",
    "Links" : "Lingid",
    "Federated sent" : "Liitpilve saadetud",
    "Federated received" : "Liitpilvest vastu võetud",
    "Last 24 hours" : "Viimased 24 tundi",
    "Last 1 hour" : "Viimane 1 tund",
    "Last 5 mins" : "Viimased 5 minutit",
    "Monitoring" : "Monitooring",
    "CPU load" : "CPU koormus",
    "Memory usage" : "Mälukasutus",
    "Active users" : "Aktiivseid kasutajaid",
    "Shares" : "Jagamisi",
    "Storage" : "Andmehoidlad",
    "Users:" : "Kasutajaid:",
    "Files:" : "Faile:",
    "PHP" : "PHP",
    "Version:" : "Versioon:",
    "Memory Limit:" : "Mälupiirang:",
    "Max Execution Time:" : "Maksimaalne käivitusaeg:",
    "Upload max size:" : "Maksimaalne üleslaadimissuurus:",
    "Database" : "Andmebaas",
    "Type:" : "Tüüp:",
    "Size:" : "Suurus:",
    "External monitoring tool" : "Väline monitoorimistööriist",
    "You can connect an external monitoring tool by using this end point: " : "Saad ühendada välise monitoorimistööriista kasutades seda lõpp-punkti:",
    "Server info" : "Serveri info",
    "You can connect a external monitoring tool by using this end point: " : "Saad ühendada välise monitoorimistööriista kasutades seda lõpp-punkti:"
},
"nplurals=2; plural=(n != 1);");
